@@ -1,4 +1,11 @@
-<? $treefile = "layersmenu.txt"; ?>
+<?
+$treefile = "layersmenu.txt";
+
+$abscissa_step = 140;
+$abscissa_stepx5 = $abscissa_step*5;
+$ordinata_step = 15;
+$ordinata[2] = 15-$ordinata_step;
+?>
 
 <script language="JavaScript">
 <!--
@@ -109,12 +116,8 @@ while ($buffer = fgets($fd, 4096)) {
 
 /* ******************************************************************** */
 
-$abscissa_step = 140;
-$abscissa_stepx5 = $abscissa_step*5;
 for ($i=0; $i<$maxlevel; $i++)
 	$abscissa[$i] = $i * $abscissa_step;
-$ordinata_step = 15;
-$ordinata[2] = 15-$ordinata_step;
 
 for ($cnt=1; $cnt<count($tree); $cnt++) {
 	$layername[$tree[$cnt][0]] = $stripped_tree[$cnt];
