@@ -137,6 +137,13 @@ function delete_brand($id) {
 
 	$qid = db_begin();
 
+	/* find out the brand name */
+	$qid = db_query("
+	SELECT name from brands
+	WHERE id = '$id'
+	");
+	$frm = db_fetch_array($qid, 0);
+
 	/* delete this brand */
 	$qid = db_query("
 	DELETE FROM brands
@@ -259,9 +266,6 @@ function import_brands($userfile) {
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 
-		$arr = db_fetch_array($qid,0);
-		$pid = $arr[0];
-
 //		/* Stripping dangerous characters from fields */
 //		$fldarr[0] = ereg_replace("\'","",$fldarr[0]);
 		$fldarr[0] = ereg_replace("'","\'",$fldarr[0]);
