@@ -191,15 +191,37 @@ function delete_category($id) {
 	// delete products in this category that also belong
 	// to the parent category, to avoid duplicates forbidden
 	// by the primary key constraint
+/* Nested queries aren't still supported by MySQL :(
+ *	$qid = db_query("
+ *		DELETE FROM products_categories WHERE ( product_id,category_id ) IN (
+ *			SELECT * FROM products_categories pc WHERE category_id = '$id' AND
+ *			EXISTS (
+ *				SELECT * FROM products_categories
+ *				WHERE product_id = pc.product_id
+ *					AND category_id = '$cat->parent_id'
+ *			)
+ *		)
+ *	");
+ * a workaround in the following */
 	$qid = db_query("
-		DELETE FROM products_categories WHERE ( product_id,category_id ) IN (
-			SELECT * FROM products_categories pc WHERE category_id = '$id' AND
-			EXISTS (
-				SELECT * FROM products_categories
-				WHERE product_id = pc.product_id
-					AND category_id = '$cat->parent_id'
-			)
-		)
+		SELECT pc1.product_id
+		FROM products_categories pc1 , products_categories pc2
+		WHERE
+			pc1.product_id = pc2.product_id
+			AND pc1.category_id = '$cat->parent_id'
+			AND pc2.category_id = '$id'
+	");
+	$numr = db_num_rows($qid);
+	$toberemoved = "";
+	for ($i=0; $i<$numr-1; $i++) {
+		$appoggio = db_fetch_object($qid, $i);
+		$toberemoved .= "'" . $appoggio->product_id . "', ";
+	}
+	$appoggio = db_fetch_object($qid, $numr-1);
+	$toberemoved .= "'" . $appoggio->product_id . "'";
+	$qid = db_query("
+		DELETE FROM products_categories
+		WHERE category_id = '$id' AND product_id IN ($toberemoved)
 	");
 
 	/* re-assign all the products in this category to the parent category */
