@@ -234,6 +234,9 @@ function import_iva($userfile) {
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 
+		$arr = db_fetch_array($qid,0);
+		$pid = $arr[0];
+
 		/* Stripping dangerous characters from fields */
 		$fldarr[0] = ereg_replace("\'","",$fldarr[0]);
 
