@@ -161,6 +161,7 @@ switch (nvl($mode)) {
 			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["extended_description"] = $HTTP_POST_VARS["extended_description"];
+			$frm["delete_image"] = $HTTP_POST_VARS["delete_image"];
 			$frm["submit_caption"] = $Save_Changes;
 			/* build the categories listbox options, preselect the top item */
 			build_category_tree($category_options, $frm["categories"]);
@@ -554,7 +555,19 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 }
 */
 
-	if ($HTTP_POST_FILES['userfile']['tmp_name'] == "none") {
+	if ($frm[delete_image]) {
+		$upload_path = $CFG->productsdir;
+		$old_upload_name = $upload_path.string_cleanup($frm[old_product_id]);
+		$old_upload_name_thumb = $old_upload_name.".thumb.jpg";
+		system ("rm -f $old_upload_name_thumb", $result);
+		$old_upload_name .= ".".$frm["old_imagetype"];
+		system ("rm -f $old_upload_name", $result);
+		$imagewidth = "";
+		$imageheight = "";
+		$thumbwidth = "";
+		$thumbheight = "";
+		$type = "";
+	} else if ($HTTP_POST_FILES['userfile']['tmp_name'] == "none") {
 		echo "<div class=normal>" . $no_product_image_chosen . "</div>";
 		if ($frm[old_product_id] != $frm[product_id] && $frm["old_imagetype"] != "") {
 			$upload_path = $CFG->productsdir;
@@ -675,7 +688,7 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 }
 
 function print_product_list() {
-/* read all the categories from the database and print them into a table.  we
+/* read all the products from the database and print them into a table.  we
  * will use a template to display the listings to keep this main script clean */
 
 	global $CFG, $ME;
@@ -686,7 +699,7 @@ function print_product_list() {
 
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
-		SELECT p.id AS product_id, p.name, p.brand_id, p.price,
+		SELECT p.id AS product_id, p.name, p.price,
 			p.iva_id, p.discount, p.discqty, p.weight,
 			p.description, p.extended_description,
 			p.imagetype, p.imagewidth, p.imageheight,
