@@ -229,7 +229,6 @@ function print_add_user_form($usertype) {
 	global $CFG, $ME;
 	global $SESSION;
 	global $page_number, $dbchanged;
-	global $yes;
 	include ($CFG->global);
 
 	/* set default values for the reset of the fields */
@@ -245,8 +244,8 @@ function print_add_user_form($usertype) {
 	$frm["fax"] = "";
 	$frm["mobilephone"] = "";
 	$frm["email"] = "";
-	$frm["authdata"] = "";
-	$frm["acceptadvert"] = $yes;
+	$frm["authdata"] = 0;
+	$frm["acceptadvert"] = 1;
 	$frm["notes"] = "";
 
 	$frm["newmode"] = "insert";
@@ -261,7 +260,6 @@ function print_edit_user_form($username) {
 	global $CFG, $ME;
 	global $SESSION;
 	global $page_number, $dbchanged;
-	global $yes;
 	include ($CFG->global);
 
 	/* load up the information for the user */
@@ -301,6 +299,7 @@ function insert_user($frm) {
 
 	global $CFG, $SESSION;
 	global $myday, $mymonth;
+	include ($CFG->global);
 
 	$date = $myday[date("w")] . date(" j") . "-" . date("n") . "-" . date("Y H:i:s");
 	$fromip = getenv("REMOTE_ADDR");
@@ -309,11 +308,30 @@ function insert_user($frm) {
 
 	$qid = db_query("
 	INSERT INTO users (
-		username, password, usertype, priv, firstname, lastname,
-		fiscalcode, address, number, city, state, zip_code,
-		phone, fax, mobilephone, email,
-		authdata, acceptadvert, notes, ournotes, date, fromip
-	) VALUES (
+		username
+		,password
+		,usertype
+		,priv
+		,firstname
+		,lastname
+		,fiscalcode
+		,address
+		,number
+		,city
+		,state
+		,zip_code
+		,phone
+		,fax
+		,mobilephone
+		,email
+		,authdata
+		,acceptadvert
+		,notes
+		,ournotes
+		,date
+		,fromip
+		)
+	VALUES (
 		 '$frm[username]'
 		,'" . md5($password) ."'
 		,'$frm[usertype]'
@@ -378,6 +396,7 @@ function print_user_list() {
 
 	global $CFG, $ME;
 	global $SESSION;
+	global $yes;
 	global $page_number, $dbchanged;
 	include ($CFG->global);
 
@@ -487,11 +506,30 @@ function import_users($userfile) {
 			/* ... if it doesn't exist let's create it in the users table ... */
 			$qid = db_query("
 			INSERT INTO users (
-				username, password, usertype, priv, firstname, lastname,
-				fiscalcode, address, number, city, state, zip_code,
-				phone, fax, mobilephone, email,
-				authdata, acceptadvert, notes, ournotes, date, fromip
-			) VALUES (
+				username
+				,password
+				,usertype
+				,priv
+				,firstname
+				,lastname
+				,fiscalcode
+				,address
+				,number
+				,city
+				,state
+				,zip_code
+				,phone
+				,fax
+				,mobilephone
+				,email
+				,authdata
+				,acceptadvert
+				,notes
+				,ournotes
+				,date
+				,fromip
+				)
+			VALUES (
 		 		'$fldarr[0]'
 				,'" . md5($fldarr[1]) ."'
 				,'$fldarr[2]'
