@@ -116,22 +116,22 @@ $CFG->global = $CFG->localedir.$SESSION["lang"]."/global.inc.php";
 
 include ($CFG->global);
 
-//$dollars = "Lit";
-$dollars = "$";
+//$currency = "Lit";
+$currency = "$";
 function print_formatted_price($price) {
-	global $dollars, $lire2euro;
-//	echo $dollars . " " . number_format ($price, 0, ",", ".");
-	echo $dollars . " " . number_format ($price, 2, ".", ",");
+	global $currency, $lire2euro;
+//	echo $currency . " " . number_format ($price, 0, ",", ".");
+	echo $currency . " " . number_format ($price, 2, ".", ",");
 }
 function formatted_price($price) {
-	global $dollars, $lire2euro;
-//	return $dollars . " " . number_format ($price, 0, ",", ".");
-	return $dollars . " " . number_format ($price, 2, ".", ",");
+	global $currency, $lire2euro;
+//	return $currency . " " . number_format ($price, 0, ",", ".");
+	return $currency . " " . number_format ($price, 2, ".", ",");
 }
 function formatted_price_text($price) {
-	global $dollars, $lire2euro;
-//	return $dollars . " " . number_format ($price, 0, ",", ".");
-	return $dollars . " " . number_format ($price, 2, ".", ",");
+	global $currency, $lire2euro;
+//	return $currency . " " . number_format ($price, 0, ",", ".");
+	return $currency . " " . number_format ($price, 2, ".", ",");
 }
 
 $weightunity = "Kg";
