@@ -116,26 +116,26 @@ $CFG->global = $CFG->localedir.$SESSION["lang"]."/global.inc.php";
 
 include ($CFG->global);
 
-$dollars = "Lit";
+$currency = "Lit";
 $lire2euro = 1936.27;
-//$dollars = "$";
+//$currency = "$";
 function print_formatted_price($price) {
-	global $dollars, $lire2euro;
-	echo $dollars . " " . number_format ($price, 0, ",", ".") . "<br>&euro; " . number_format ($price/$lire2euro, 2, ",", ".");
-//	echo $dollars . " " . number_format ($price, 0, ",", ".");
-//	echo $dollars . " " . number_format ($price, 2, ".", ",");
+	global $currency, $lire2euro;
+	echo $currency . " " . number_format ($price, 0, ",", ".") . "<br>&euro; " . number_format ($price/$lire2euro, 2, ",", ".");
+//	echo $currency . " " . number_format ($price, 0, ",", ".");
+//	echo $currency . " " . number_format ($price, 2, ".", ",");
 }
 function formatted_price($price) {
-	global $dollars, $lire2euro;
-	return $dollars . " " . number_format ($price, 0, ",", ".") . "<br>&euro; " . number_format ($price/$lire2euro, 2, ",", ".");
-//	return $dollars . " " . number_format ($price, 0, ",", ".");
-//	return $dollars . " " . number_format ($price, 2, ".", ",");
+	global $currency, $lire2euro;
+	return $currency . " " . number_format ($price, 0, ",", ".") . "<br>&euro; " . number_format ($price/$lire2euro, 2, ",", ".");
+//	return $currency . " " . number_format ($price, 0, ",", ".");
+//	return $currency . " " . number_format ($price, 2, ".", ",");
 }
 function formatted_price_text($price) {
-	global $dollars, $lire2euro;
-	return $dollars . " " . number_format ($price, 0, ",", ".") . " - Euro " . number_format ($price/$lire2euro, 2, ",", ".");
-//	return $dollars . " " . number_format ($price, 0, ",", ".");
-//	return $dollars . " " . number_format ($price, 2, ".", ",");
+	global $currency, $lire2euro;
+	return $currency . " " . number_format ($price, 0, ",", ".") . " - Euro " . number_format ($price/$lire2euro, 2, ",", ".");
+//	return $currency . " " . number_format ($price, 0, ",", ".");
+//	return $currency . " " . number_format ($price, 2, ".", ",");
 }
 
 $weightunity = "Kg";
