@@ -68,6 +68,7 @@ $Payment_Methods = "Metodi di pagamento";
 $Add_to_cart = "+ Aggiungi al carrello";
 $Add_to_Shopping_Cart = "+ Aggiungi al carrello della spesa";
 $Image = "Immagine";
+$Delete_Actual_Image = "Elimina Immagine Attuale (lascia il prodotto senza immagine)";
 $Notes = "Annotazioni";
 $Our_Notes = "Nostre Annotazioni";
 $Change_Settings = "Modifica Impostazioni";
@@ -193,7 +194,6 @@ $Purchase_Price = "Prezzo d'acquisto";
 $Order_State = "Stato dell'ordine";
 $Orders_States = "Stati degli ordini";
 $ID_and_State = "ID - Stato";
-$StateO = "Stato";
 $Cust_Info = "Info cliente";
 $Details = "Dettagli";
 $Special_Flag = "Prodotto Speciale";
