@@ -68,6 +68,7 @@ $Payment_Methods = "Payment Methods";
 $Add_to_cart = "+ Add to cart";
 $Add_to_Shopping_Cart = "+ Add to Shopping Cart";
 $Image = "Image";
+$Delete_Actual_Image = "Delete Actual Image (leave the product without any image)";
 $Notes = "Notes";
 $Our_Notes = "Our Notes";
 $Change_Settings = "Change Settings";
@@ -193,7 +194,6 @@ $Purchase_Price = "Purchase Price";
 $Order_State = "Order State";
 $Orders_States = "Orders States";
 $ID_and_State = "ID - State";
-$StateO = "State";
 $Cust_Info = "Cust. Info";
 $Details = "Details";
 $Special_Flag = "Special Product";
