@@ -38,10 +38,10 @@ include("$CFG->templatedir"."footer.ihtml");
 function get_sub_categories($id=1) {
 /* get the name and description of all the sub-categories under this one */
 
-	$qid = db_query("SELECT id, name, on_special, description
+	$qid = db_query("SELECT id, name, special_level, description
 			FROM categories
 			WHERE parent_id = '$id' AND id > 1
-			ORDER BY on_special, name
+			ORDER BY special_level, name
 			");
 	return $qid;
 }
@@ -58,7 +58,8 @@ function get_products($category_id=1) {
 		,p.discount
 		,p.discqty
 		,p.weight
-		,p.on_special
+		,p.special_flag
+		,p.special_level
 		,p.description
 		,p.imagetype
 		,p.imagewidth
@@ -69,7 +70,7 @@ function get_products($category_id=1) {
 		,b.name AS bname
 	FROM products p JOIN products_categories pc ON (p.id = pc.product_id) JOIN brands b ON (p.brand_id = b.id)
 	WHERE pc.category_id = '$category_id'
-	ORDER BY p.on_special ASC
+	ORDER BY p.special_level ASC
 	");
 
 	return $qid;
