@@ -60,13 +60,14 @@ function load_product($product_id) {
 	$qid = db_query("
 	SELECT
 		 p.id
-		,p.name
+		,p.name AS name
 		,p.price
 		,p.iva_id
 		,p.discount
 		,p.discqty
 		,p.weight
-		,p.on_special
+		,p.special_flag
+		,p.special_level
 		,p.description
 		,p.extended_description
 		,p.imagetype
@@ -75,7 +76,7 @@ function load_product($product_id) {
 		,p.thumbwidth
 		,p.thumbheight
 		,pc.category_id
-		,b.name
+		,b.name AS bname
 	FROM products p JOIN products_categories pc ON (p.id = pc.product_id) JOIN brands b ON (p.brand_id = b.id)
 	WHERE p.id = '$product_id'
 	");
