@@ -31,7 +31,7 @@ $DOC_TITLE = $Contact_Us;
 include("$CFG->templatedir"."header.ihtml");
 include("$CFG->templatedir"."form_header.ihtml");
 if (empty($errormsg)) {	// we are loading the form for the first time
-	$frm["acceptadvert"] = $yes;
+	$frm["acceptadvert"] = 1;
 }
 include("templates/contact_form.ihtml");
 include("$CFG->templatedir"."footer.ihtml");
@@ -81,8 +81,10 @@ function send_form(&$frm) {
 	$emailbody .= "\n\n" . $contact[Fax] . $frm["fax"];
 	$emailbody .= "\n\n" . $contact[MobilePhone] . $frm["mobilephone"];
 	$emailbody .= "\n\n" . $contact[EMail] . $frm["email"];
-	$emailbody .= "\n\n" . $contact[AuthData] . strtoupper($frm["authdata"]);
-	$emailbody .= "\n\n" . $contact[AuthAdvert] . strtoupper($frm["acceptadvert"]);
+	$emailbody .= "\n\n" . $contact[AuthData];
+	if ($frm["authdata"]) $emailbody .= strtoupper($yes);
+	$emailbody .= "\n\n" . $contact[AuthAdvert];
+	if ($frm["acceptadvert"]) $emailbody .= strtoupper($yes);
 	$emailbody .= "\n\n" . $contact[Message] . "\n\n" . stripslashes($frm["message"]) . "\n";
 
 	mail(
